@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Iterator::Rule;
 # ABSTRACT: Iterative, recursive file finder
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 # Register warnings category
 use warnings::register;
@@ -564,7 +564,7 @@ Path::Iterator::Rule - Iterative, recursive file finder
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -647,7 +647,7 @@ case it still returns a new object that matches any file or directory.
 =head3 C<clone>
 
   my $common      = Path::Iterator::Rule->new->file->not_empty;
-  my $big_files   = $common->clone->size(">1MB");
+  my $big_files   = $common->clone->size(">1M");
   my $small_files = $common->clone->size("<10K");
 
 Creates a copy of a rule object.  Useful for customizing different
